@@ -1,6 +1,7 @@
 from progression_qc.progression_qc import *
 import progression_qc
 import traceback
+import urllib
 
 if __name__ == "__main__":
     args = traiter_paramètres()
@@ -14,13 +15,13 @@ if __name__ == "__main__":
             infos_question = charger_question(args.fichier, get_readers())
             resultats = valider_schema_yaml_infos_question(infos_question)
             resultats["infos_question"] = infos_question
-        except Exception as e:
+            code_retour = déterminer_code_retour(resultats)
+        except (urllib.error.HTTPError, urllib.error.URLError) as e:
+            code_retour = 255
             if args.verbose:
                 print(traceback.format_exc(), file=sys.stderr)
             resultats = {"erreurs": {args.fichier: e}}
 
-        code_retour = déterminer_code_retour(resultats)
-
         if not args.quiet:
             if args.json:
                 afficher_résultats_json(resultats)
